@@ -25,32 +25,24 @@ class DescribeExecutionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'fnf', '2019-03-15', 'DescribeExecution','fnf')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ExecutionName(self):
+	def get_ExecutionName(self): # String
 		return self.get_query_params().get('ExecutionName')
 
-	def set_ExecutionName(self,ExecutionName):
-		self.add_query_param('ExecutionName',ExecutionName)
-
-	def get_WaitTimeSeconds(self):
+	def set_ExecutionName(self, ExecutionName):  # String
+		self.add_query_param('ExecutionName', ExecutionName)
+	def get_WaitTimeSeconds(self): # Integer
 		return self.get_query_params().get('WaitTimeSeconds')
 
-	def set_WaitTimeSeconds(self,WaitTimeSeconds):
-		self.add_query_param('WaitTimeSeconds',WaitTimeSeconds)
-
-	def get_RequestId(self):
-		return self.get_query_params().get('RequestId')
-
-	def set_RequestId(self,RequestId):
-		self.add_query_param('RequestId',RequestId)
-
-	def get_FlowName(self):
+	def set_WaitTimeSeconds(self, WaitTimeSeconds):  # Integer
+		self.add_query_param('WaitTimeSeconds', WaitTimeSeconds)
+	def get_FlowName(self): # String
 		return self.get_query_params().get('FlowName')
 
-	def set_FlowName(self,FlowName):
-		self.add_query_param('FlowName',FlowName)
\ No newline at end of file
+	def set_FlowName(self, FlowName):  # String
+		self.add_query_param('FlowName', FlowName)
