@@ -25,56 +25,44 @@ class ListExecutionsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'fnf', '2019-03-15', 'ListExecutions','fnf')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_StartedTimeBegin(self):
+	def get_StartedTimeBegin(self): # String
 		return self.get_query_params().get('StartedTimeBegin')
 
-	def set_StartedTimeBegin(self,StartedTimeBegin):
-		self.add_query_param('StartedTimeBegin',StartedTimeBegin)
-
-	def get_ExecutionNamePrefix(self):
+	def set_StartedTimeBegin(self, StartedTimeBegin):  # String
+		self.add_query_param('StartedTimeBegin', StartedTimeBegin)
+	def get_ExecutionNamePrefix(self): # String
 		return self.get_query_params().get('ExecutionNamePrefix')
 
-	def set_ExecutionNamePrefix(self,ExecutionNamePrefix):
-		self.add_query_param('ExecutionNamePrefix',ExecutionNamePrefix)
-
-	def get_NextToken(self):
+	def set_ExecutionNamePrefix(self, ExecutionNamePrefix):  # String
+		self.add_query_param('ExecutionNamePrefix', ExecutionNamePrefix)
+	def get_NextToken(self): # String
 		return self.get_query_params().get('NextToken')
 
-	def set_NextToken(self,NextToken):
-		self.add_query_param('NextToken',NextToken)
-
-	def get_RequestId(self):
-		return self.get_query_params().get('RequestId')
-
-	def set_RequestId(self,RequestId):
-		self.add_query_param('RequestId',RequestId)
-
-	def get_Limit(self):
+	def set_NextToken(self, NextToken):  # String
+		self.add_query_param('NextToken', NextToken)
+	def get_Limit(self): # Integer
 		return self.get_query_params().get('Limit')
 
-	def set_Limit(self,Limit):
-		self.add_query_param('Limit',Limit)
-
-	def get_FlowName(self):
+	def set_Limit(self, Limit):  # Integer
+		self.add_query_param('Limit', Limit)
+	def get_FlowName(self): # String
 		return self.get_query_params().get('FlowName')
 
-	def set_FlowName(self,FlowName):
-		self.add_query_param('FlowName',FlowName)
-
-	def get_StartedTimeEnd(self):
+	def set_FlowName(self, FlowName):  # String
+		self.add_query_param('FlowName', FlowName)
+	def get_StartedTimeEnd(self): # String
 		return self.get_query_params().get('StartedTimeEnd')
 
-	def set_StartedTimeEnd(self,StartedTimeEnd):
-		self.add_query_param('StartedTimeEnd',StartedTimeEnd)
-
-	def get_Status(self):
+	def set_StartedTimeEnd(self, StartedTimeEnd):  # String
+		self.add_query_param('StartedTimeEnd', StartedTimeEnd)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
